clear
clear mata
set memory 500m

use  "Cap10_DataCotonou", clear

***************************************************************************************************************
***********************************Labeling Variables**********************************************************
***************************************************************************************************************

rename trade_gallez imp

label variable util_acp "Ratio of EU actual imports under Cotonou scheme to the value of total imports, computed at the country-HS6 product line level"

label variable m_acp "Preferential margin computed as (MFNik - PREFik)/MFNik"

label variable imp "EU import flows from Cotonou eligible countries, at the HS6-digit level

label variable lngdp "log of GDP of exporting country"

label variable lnpop "log of population of exporting country"

label variable lndist "log of the distance, in kilometres, between each exporter i and the EU"

label variable comlang "Dummy = 1 if the exp. country language is spoken in at least one EU states"

label variable colony "Dummy = 1 if colonial links existed between the exporter and at least one EU states"

label variable free_index "Heritage Foundation and Wall Street Journal Freedom Index"

label variable id_exp "Identity of exporting country

*********************************************************************
*A) TOBIT model to retrieve measure of compliance costs)
*********************************************************************

xi: tobit util_acp   m_acp  lngdp lnpop lndis comlang colony free_index , ll(0) ul(100) cluster(id_exp)

predict y_fit if e(sample), xb 
g costs_acp=(util_acp-y_fit)
drop y_fit
sum costs_acp
g costs_acp2=(1082.61- costs_acp)
sum  costs_acp2 


g lncosts_acp=ln(1+costs_acp2)
g lnmarg_acp=ln(1+ m_acp)
g int_acp=lnmarg_acp*lncosts_acp
 


centile(lncosts_acp), centile(1,99)


drop if lncosts_acp<   4.342206
drop if lncosts_acp>     6.696539  & lncosts_acp!=.


replace imp=imp/1000000



***********************
*B) POISSON MODEL
***********************

xi: poisson imp lnmarg_acp lncosts_acp  int_acp i.id_exp , cluster (nc_6) difficult technique(bfgs)

test lnmarg_acp lncosts_acp  int_acp 
test lnmarg_acp  int_acp 



**************
* c) NEG_BIN
**************
replace imp =imp *1000000

xi: nbreg imp lnmarg_acp lncosts_acp  int_acp  i.id_exp , cluster (nc_6) difficult

test lnmarg_acp lncosts_acp  int_acp 
test lnmarg_acp  int_acp 


