* This STATA program produces some standard meta-analysis.
clear
capture log close
log using CAP5, text replace
use CAP5DATA.dta

bysort dummy_policy: sum gamma, d
gen outlier = 1 if gamma < -21 & dummy_policy == 0
replace outlier= 1 if gamma > 8 & dummy_policy == 0
replace outlier= 1 if gamma < -5 & dummy_policy == 1
replace outlier= 1 if gamma > 3 & dummy_policy == 1
replace outlier = 0 if outlier == .

* PART A

gen tratio=gamma/segamma
gen invse=1/segamma
gen nocountry_se=nocountry/segamma
gen notime_se=notime/segamma
gen cross_se=cross/segamma
gen year70s_se=year70s/segamma
gen year80s_se=year80s/segamma
gen year90s_se=year90s/segamma
gen year2000s_se=year2000s/segamma
gen aggr_data_se=aggr_data/segamma
gen agg_eu_se=agg_eu/segamma
gen agriculture_se=agriculture/segamma
gen nozero_se=nozero/segamma
gen GMM_se=GMM/segamma
gen HTM_se=HTM/segamma
gen Heck_se=Heckman/segamma
gen Poisson_se=Poisson/segamma
gen Tobit_se=Tobit/segamma
gen over_se=overdispertion/segamma 
gen unpublished_se=unpublished/segamma
gen outlier_se=outlier/segamma
gen pta_se=pta/segamma
gen acp_se=acp/segamma
gen eba_se=eba/segamma
gen euromed_se=euromed/segamma
gen gsp_se=gsp/segamma
gen gspplus_se=gspplus/segamma


label var tratio "t-statistic for gamma"
label var invse "1/Se" 
label var nocountry_se "No-country effects"
label var notime_se "No-time effects"
label var cross_se "Cross-section"
label var year70s_se "1970s"
label var year80s_se "1980s"
label var year90s_se "1990s"
label var year2000s_se "2000s"
label var aggr_data_se "Aggregated data"
label var agg_eu_se "Aggregated EU"
label var agriculture_se "Agriculture"
label var nozero_se "No-zero Treatment"
label var GMM_se "GMM"
label var HTM_se "Hausman-Taylor"
label var Heck_se "Heckman"
label var Poisson_se "Poisson"
label var Tobit_se "Tobit"
label var over_se "ZIP/Negative Binomial"
label var unpublished_se "Unpublished"
label var outlier_se "Outliers"
label var pta_se "PTAs"
label var acp_se "ACP"
label var eba_se "EBA"
label var euromed_se "Euro-Med"
label var gsp_se "GSP"
label var gspplus_se "GSP-Plus"

* PART B

gen pgamma=ttail(obs,tratio)
replace pgamma=1.e-20 if pgamma==0.
label var pgamma "P-value for gamma"
metap pgamma if  dummy_policy==1, method(f)
metap pgamma if  dummy_policy==0, method(f)

* PART C

meta gamma segamma if  dummy_policy==1
meta gamma segamma if  dummy_policy==0

meta gamma segamma if dummy_policy==1 & acp==1 
meta gamma segamma if dummy_policy==1 & eba==1 
meta gamma segamma if dummy_policy==1 & euromed==1 
meta gamma segamma if dummy_policy==1 & gsp==1 
meta gamma segamma if dummy_policy==1 & gspplus==1 
meta gamma segamma if dummy_policy==0 & acp==1 
meta gamma segamma if dummy_policy==0 & eba==1 
meta gamma segamma if dummy_policy==0 & euromed==1 
meta gamma segamma if dummy_policy==0 & gsp==1 
meta gamma segamma if dummy_policy==0 & gspplus==1 

* PART D

eststo clear 
eststo: reg  tratio invse nocountry_se notime_se cross_se year70s_se year80s_se year90s_se year2000s_se aggr_data_se agg_eu_se agriculture_se nozero_se GMM_se HTM_se Heck_se Poisson_se Tobit_se over_se unpublished_se outlier_se pta_se if dummy_policy==1, robust cluster(paper)
eststo: reg  tratio invse nocountry_se notime_se cross_se year70s_se year80s_se year90s_se year2000s_se aggr_data_se agg_eu_se agriculture_se nozero_se GMM_se HTM_se Heck_se Poisson_se Tobit_se over_se unpublished_se outlier_se  acp_se eba_se euromed_se gsp_se gspplus_se if dummy_policy==1, robust cluster(paper)
esttab using CAP5.doc, title (Table 5.5 - MRA of PTAs effects for papers using dummies for PTAs) se ar2 label replace rtf b(2) star(* 0.10 ** 0.05 *** 0.01) se(2) mti 

eststo clear
eststo: reg  tratio invse nocountry_se notime_se cross_se year2000s_se agg_eu_se Heck_se Poisson_se over_se unpublished_se outlier_se pta_se if dummy_policy==0, robust cluster(paper)
eststo: reg  tratio invse nocountry_se notime_se cross_se year2000s_se agg_eu_se Heck_se Poisson_se over_se unpublished_se outlier_se acp_se eba_se euromed_se gsp_se gspplus_se if dummy_policy==0, robust cluster(paper)
esttab using CAP5.doc, title (Table 5.6 - MRA of PTAs effects for papers using preference margins for PTAs) se ar2 label replace rtf b(2) star(* 0.10 ** 0.05 *** 0.01) se(2) mti append

* PART E

funnel segamma gamma if dummy_policy == 1, xlab title (Figure 5.1) saving (Figure_5.1.gph, replace)
funnel segamma gamma if dummy_policy == 0, xlab title (Figure 5.2) saving (Figure_5.2.gph, replace)

metabias gamma segamma if dummy_policy == 1, graph (egger) saving (Figure_5.1_Egger.gph, replace)
metabias gamma segamma if dummy_policy == 0, graph (egger) saving (Figure_5.2_Egger.gph, replace)

log close


























