clear 
set maxvar 3072
set matsize 5000
set mem 900m
capture log close
log using "CAP6.log", replace

use CAP6Dataset.dta

*PART A: Variable Generation

g pref_top=(1+tmax)/(1+ut)
g lpref=ln(1+tmax)-ln(1+ut)
g lpreftr=lpref*preftr

g prtr=0 if ltrade==.
replace prtr=1 if prtr==.

la var ldist "ln dij"
la var colony "Cij"
la var lang "Lij"
la var lpref "ln(1+prefijk)"
la var lpreftr "ln(1+prefijk)*PRE"

save CAP6Dataset_def.dta, replace

*PART B: Summary Statistics 

egen totaltrade=total(trade)
egen totpreftrade=total(trade) if preftr==1
egen totfreetrade=total(trade) if mfn==0
egen totmfntrade=total(trade) if mfn>0 & preftr==0
bysort section: egen tottrade_sector=total(trade)
bysort section: egen totpreftrade_sector=total(trade) if preftr==1
bysort section: egen totfreetrade_sector=total(trade) if mfn==0
bysort section: egen totmfntrade_sector=total(trade) if mfn>0 & preftr==0

tabstat totaltrade totpreftrade totfreetrade totmfntrade if trade>0, stat(mean)
tabstat tottrade_sector totfreetrade_sector totmfntrade_sector totpreftrade_sector  if trade>0 , by(section) stat(mean) 

g valueofpref=(tmax-ut)*trade if preftr==1
bysort section:egen tot_value_sec=total(valueofpref)
egen tot_value=total(valueofpref)

tabstat ut pref_top if trade>0 & preftr==1, stats (mean sd ) col(stat)
tabstat tot_value, stats (mean ) col(stat)
tabstat ut  pref_top if trade>0 & preftr==1, by(section) stats (mean sd ) col(stat)
tabstat tot_value_sec, by(section) stats (mean ) col(stat)

*PART C: Regression Specifications 


clear
use CAP6Dataset_def.dta
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs2, gen(dhs2)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs2*, select(ldist lpref colony lang dexp* dimp* dhs2*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs2* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(overall) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin 

clear
use CAP6Dataset_def.dta
keep if section==1
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section I) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==2
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section II) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==3
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section III) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==4
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section IV) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==6
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section V) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==7
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section VII) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==8
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section VIII) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==9
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section IX) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==11
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XI) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==12
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XII) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==13
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XIII) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==14
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XIV) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==15
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XV) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==16
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XVI) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==17
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XVII) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append

clear
use CAP6Dataset_def.dta
keep if section==18
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XVIII) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append



clear
use CAP6Dataset_def.dta
keep if section==20
qui tab exp, gen(dexp)
qui tab imp, gen(dimp)
qui tab hs6, gen(dhs6)
heckman ltrade ldist lpreftr colony dexp* dimp* dhs6*, select(ldist lpref colony lang dexp* dimp* dhs6*) twostep
est sto Heckman
adjust, g(ywithpref)
adjust lpreftr=0, g(ynopref)
sum ywithpref ynopref
dprobit prtr ldist lpref lang colony dexp* dimp* dhs6* if e(sample)
est sto Probit_MargEff
esttab Heckman Probit_MargEff using CAP6N.doc, title(section XX) ar2 se pr2 label replace rtf b(2) se(2) mti (no)constant star(* 0.10 ** 0.05 *** 0.01)  keep(ldist lpreftr lpref colony lang lambda) margin append


*End of do file
